using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;

namespace ScrollBar //The namespace name is not important.
{

	//Inherit from IDisposable if you need Basic4ppc to free resources when the application is closed.
	public class ScrollBar:IDisposable 
	{
		private System.Windows.Forms.ScrollBar sb; //The "real" object.
		public event EventHandler ValueChanged; //The event handler name must match the event name.
		private object[] eventObject; //One object[] for each event (one event here).
		
		//At least one public ctor.
		public ScrollBar(Control FormName, int Left, int Top, int Width, int Height, bool IsVertical)
		{
			if (IsVertical)
				sb = new VScrollBar();
			else
				sb = new HScrollBar();
			sb.Left = Left;
			sb.Top = Top;
			sb.Width = Width;
			sb.Height = Height;
			FormName.Controls.Add(sb);
			eventObject = new object[] {this,"ValueChanged"}; //This is the object that will pass with the event.
			//It must be in that format exactly.

			sb.ValueChanged += new EventHandler(sb_ValueChanged);
		}
		public double DLLVersion
		{
			get {return 1;}
		}
		//Use properties to allow syntax like: bar.Height = 50 OR x = bar.Height
		//The Control property returns the real control.
		public System.Windows.Forms.ScrollBar Control
		{
			get {return sb;}
			set {sb = value;}
		}
		public int Value
		{
			get {return sb.Value;}
			set {sb.Value = value;}
		}
		public int Height
		{
			get {return sb.Height;}
			set {sb.Height = value;}
		}
		public int Width
		{
			get {return sb.Width;}
			set {sb.Width = value;}
		}
		public int Left
		{
			get {return sb.Left;}
			set {sb.Left = value;}
		}
		public int Top
		{
			get {return sb.Top;}
			set {sb.Top = value;}
		}
		public int Maximum
		{
			get {return sb.Maximum;}
			set {sb.Maximum = value;}
		}
		public int Minimum
		{
			get {return sb.Minimum;}
			set {sb.Minimum = value;}
		}
		public bool Enabled
		{
			get {return sb.Enabled;}
			set {sb.Enabled = value;}
		}
		public bool Visible
		{
			get {return sb.Visible;}
			set {sb.Visible = value;}
		}
		public int LargeChange
		{
			get {return sb.LargeChange;}
			set {sb.LargeChange = value;}
		}
		public int SmallChange
		{
			get {return sb.SmallChange;}
			set {sb.SmallChange = value;}
		}

		private void sb_ValueChanged(object sender, EventArgs e)
		{
			if (ValueChanged != null) //You must test this.
			{
				ValueChanged(eventObject,null);
			}
		}
		public void Dispose()
		{
			try
			{
				ValueChanged = null;
				if (sb != null)
					sb.Dispose();
			}
			finally{}
		}

	}
}
